@@ -68,61 +68,6 @@
 #define MINIMUM_ON_SCREEN_HEIGHT	100
 
 
-/**
- * eel_gtk_button_new_with_stock_icon:
- * 
- * @label: the button label, which may include a mnemonic accelerator.
- * @stock_id: the stock icon to use.
- *
- * Creates a GtkButton with a mnemonic label and a stock icon.
- *
- * Return value: a new GtkButton widget.
- **/
-GtkWidget*
-eel_gtk_button_new_with_stock_icon (const gchar *label, const gchar *stock_id)
-{
-	GtkWidget *button, *l, *image, *hbox, *align;
-
-	/* This is mainly copied from gtk_button_construct_child(). */
-	button = gtk_button_new ();
-	l = gtk_label_new_with_mnemonic (label);
-	gtk_label_set_mnemonic_widget (GTK_LABEL (l), GTK_WIDGET (button));
-	image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON);
-	hbox = gtk_hbox_new (FALSE, 2);
-	align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
-	gtk_box_pack_end (GTK_BOX (hbox), l, FALSE, FALSE, 0);
-	gtk_container_add (GTK_CONTAINER (button), align);
-	gtk_container_add (GTK_CONTAINER (align), hbox);
-	gtk_widget_show_all (align);
-
-	return button;
-}
-
-/**
- * eel_gtk_button_set_padding
- * 
- * Adds some padding around the contained widget in the button (typically the label).
- * @button: a GtkButton
- * @pad_amount: number of pixels of space to add around the button's contents.
- * GNOME_PAD_SMALL is a typical value.
- **/
-void
-eel_gtk_button_set_padding (GtkButton *button, int pad_amount)
-{
-	GtkWidget *child;
-
-	g_return_if_fail (GTK_IS_BUTTON (button));
-	g_return_if_fail (pad_amount > 0);
-
-	child = GTK_BIN (button)->child;
-
-	if (GTK_IS_MISC (child)) {
-		gtk_misc_set_padding
-			(GTK_MISC (child), pad_amount, pad_amount);
-	}
-}
-
 /**
  * eel_gtk_signal_connect_free_data_custom:
  * 
@@ -611,32 +556,6 @@ eel_gtk_widget_set_shown (GtkWidget *widget, gboolean shown)
 	}
 }
 
-/**
- * eel_gtk_widget_set_font_by_name
- *
- * Sets the font for a widget, managing the font and style objects.
- * @widget: The widget
- **/
-void
-eel_gtk_widget_set_font_by_name (GtkWidget *widget, const char *font_name)
-{
-	PangoFontDescription *font_desc;
-	
-	g_return_if_fail (GTK_IS_WIDGET (widget));
-	g_return_if_fail (font_name != NULL);
-
-	font_desc = pango_font_description_from_string (font_name);
-
-	if (font_desc == NULL) {
-		g_warning ("Bad font name '%s'", font_name);
-		return;
-	}
-
-	gtk_widget_modify_font (widget, font_desc);
-
-	pango_font_description_free (font_desc);
-}
-
 /* This stuff is stolen from Gtk. */
 
 typedef struct DisconnectInfo {
