@@ -41,12 +41,6 @@
 #define EEL_DEFAULT_POPUP_MENU_DISPLACEMENT 	2
 #define EEL_STANDARD_CLOSE_WINDOW_CONTROL_KEY 	'w'
 
-/* GtkButton */
-GtkWidget*            eel_gtk_button_new_with_stock_icon              (const gchar	    *label,
-								       const gchar	    *stock_id);
-void                  eel_gtk_button_set_padding                      (GtkButton            *button,
-								       int                   pad_amount);
-
 /* signals */
 guint                 eel_gtk_signal_connect_free_data                (GtkObject            *object,
 								       const gchar          *name,
@@ -78,8 +72,6 @@ void                  eel_gtk_widget_set_shown                        (GtkWidget
 gboolean              eel_point_in_allocation                         (const GtkAllocation  *allocation,
 								       int                   x,
 								       int                   y);
-void                  eel_gtk_widget_set_font_by_name                 (GtkWidget            *widget,
-								       const char           *font_name);
 gboolean              eel_point_in_widget                             (GtkWidget            *widget,
 								       int                   x,
 								       int                   y);
